@@ -25,7 +25,7 @@
 
 #include <QHash>
 
-class KAssistantDialog::Private
+class Q_DECL_HIDDEN KAssistantDialog::Private
 {
 public:
     Private(KAssistantDialog *q)
@@ -36,10 +36,10 @@ public:
     KAssistantDialog *q;
     QHash<KPageWidgetItem *, bool> valid;
     QHash<KPageWidgetItem *, bool> appropriate;
-    KPageWidgetModel *pageModel;
-    QPushButton *backButton;
-    QPushButton *nextButton;
-    QPushButton *finishButton;
+    KPageWidgetModel *pageModel = nullptr;
+    QPushButton *backButton = nullptr;
+    QPushButton *nextButton = nullptr;
+    QPushButton *finishButton = nullptr;
 
     void init();
     void _k_slotUpdateButtons();
@@ -49,7 +49,7 @@ public:
         QModelIndex currentIndex;
         do {
             currentIndex = nextIndex;
-            nextIndex = currentIndex.child(0, 0);
+            nextIndex = pageModel->index(0, 0, currentIndex);
             if (!nextIndex.isValid()) {
                 nextIndex = currentIndex.sibling(currentIndex.row() + 1, 0);
             }
@@ -105,14 +105,14 @@ void KAssistantDialog::Private::init()
     backButton->setText(tr("&Back", "go back"));
     backButton->setIcon(QIcon::fromTheme(iconBack));
     backButton->setToolTip(tr("Go back one step"));
-    q->connect(backButton, SIGNAL(clicked()), q, SLOT(back()));
+    q->connect(backButton, &QAbstractButton::clicked, q, &KAssistantDialog::back);
     buttonBox->addButton(backButton, QDialogButtonBox::ActionRole);
 
     nextButton = new QPushButton;
     nextButton->setText(tr("Next", "Opposite to Back"));
     nextButton->setIcon(QIcon::fromTheme(iconNext));
     nextButton->setDefault(true);
-    q->connect(nextButton, SIGNAL(clicked()), q, SLOT(next()));
+    q->connect(nextButton, &QAbstractButton::clicked, q, &KAssistantDialog::next);
     buttonBox->addButton(nextButton, QDialogButtonBox::ActionRole);
 
     finishButton = new QPushButton;
