@@ -31,6 +31,7 @@
 
 #include <string.h>
 #include <qstandardpaths.h>
+#include <../test-config.h>
 
 /* constants for hangul (de)composition, see UAX #15 */
 #define SBase 0xAC00
@@ -94,8 +95,13 @@ bool KCharSelectData::openDataFile()
     if (!dataFile.isEmpty()) {
         return true;
     } else {
-        QFile file(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kf5/kcharselect/kcharselect-data")));
+        QString fileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kf5/kcharselect/kcharselect-data"));
+        if (fileName.isEmpty()) {
+            fileName = QStringLiteral(TOP_SRCDIR "/src/kcharselect-data"); // for autotests before installation
+        }
+        QFile file(fileName);
         if (!file.open(QIODevice::ReadOnly)) {
+            qWarning() << "Couldn't find kf5/kcharselect/kcharselect-data in the install prefix (under GenericDataLocation) nor in the builtin path" << TOP_SRCDIR;
             return false;
         }
         dataFile = file.readAll();
@@ -111,7 +117,7 @@ bool KCharSelectData::openDataFile()
         if (blocks <= 167) { // maximum possible number of blocks in BMP
             // no remapping
             remapType = -1;
-        } else if (blocks >= 174 && blocks <= 177) {
+        } else if (blocks >= 174 && blocks <= 178) {
             // remapping introduced in 5.25
             remapType = 0;
         } else {
@@ -313,7 +319,7 @@ QString KCharSelectData::name(uint c)
     } else if ((c >= 0x3400 && c <= 0x4DBF)
             || (c >= 0x4E00 && c <= 0x9FFF)
             || (c >= 0x20000 && c <= 0x2F7FF)) {
-        return QStringLiteral("CJK UNIFIED IDEOGRAPH-") + formatCode(c, 4, QString());
+        return QLatin1String("CJK UNIFIED IDEOGRAPH-") + formatCode(c, 4, QString());
     } else if (c >= 0xAC00 && c <= 0xD7AF) {
         /* compute hangul syllable name as per UAX #15 */
         int SIndex = c - SBase;
@@ -338,11 +344,11 @@ QString KCharSelectData::name(uint c)
     } else if ((c >= 0xE000 && c <= 0xF8FF) || c >= 0xF0000) {
         return QCoreApplication::translate("KCharSelectData", "<Private Use>");
     } else if ((c >= 0xF900 && c <= 0xFAFF) || (c >= 0x2F800 && c <= 0x2FFFF)) {
-        return QStringLiteral("CJK COMPATIBILITY IDEOGRAPH-") + formatCode(c, 4, QString());
+        return QLatin1String("CJK COMPATIBILITY IDEOGRAPH-") + formatCode(c, 4, QString());
     }
     quint16 unicode = mapCodePointToDataBase(c);
     if (unicode == 0xFFFF) {
-        return QStringLiteral("NON-BMP-CHARACTER-") + formatCode(c, 4, QString());
+        return QLatin1String("NON-BMP-CHARACTER-") + formatCode(c, 4, QString());
     } else {
         const uchar *data = reinterpret_cast<const uchar *>(dataFile.constData());
         const quint32 offsetBegin = qFromLittleEndian<quint32>(data + 4);
@@ -750,15 +756,15 @@ bool KCharSelectData::isCombining(uint c)
 QString KCharSelectData::display(uint c, const QFont &font)
 {
     if (!isDisplayable(c)) {
-        return QStringLiteral("<b>") + QCoreApplication::translate("KCharSelectData", "Non-printable") + QStringLiteral("</b>");
+        return QLatin1String("<b>") + QCoreApplication::translate("KCharSelectData", "Non-printable") + QLatin1String("</b>");
     } else {
-        QString s = QStringLiteral("<font size=\"+4\" face=\"") + font.family() + QStringLiteral("\">");
+        QString s = QLatin1String("<font size=\"+4\" face=\"") + font.family() + QLatin1String("\">");
         if (isCombining(c)) {
             s += displayCombining(c);
         } else {
-            s += QStringLiteral("&#") + QString::number(c) + QLatin1Char(';');
+            s += QLatin1String("&#") + QString::number(c) + QLatin1Char(';');
         }
-        s += QStringLiteral("</font>");
+        s += QLatin1String("</font>");
         return s;
     }
 }
@@ -775,8 +781,8 @@ QString KCharSelectData::displayCombining(uint c)
      * Eventually, it would be nice to determine whether the character
      * combines to the left or to the right, etc.
      */
-    QString s = QStringLiteral("&nbsp;&#") + QString::number(c) + QStringLiteral(";&nbsp;") +
-                QStringLiteral(" (ab&#") + QString::number(c) + QStringLiteral(";c)");
+    QString s = QLatin1String("&nbsp;&#") + QString::number(c) + QLatin1String(";&nbsp;") +
+                QLatin1String(" (ab&#") + QString::number(c) + QLatin1String(";c)");
     return s;
 }
 
@@ -855,7 +861,7 @@ QVector<uint> KCharSelectData::find(const QString &needle)
         searchStrings = splitString(simplified);
     }
 
-    if (searchStrings.count() == 0) {
+    if (searchStrings.isEmpty()) {
         return returnRes;
     }
 
@@ -878,7 +884,7 @@ QVector<uint> KCharSelectData::find(const QString &needle)
     }
 
     bool firstSubString = true;
-    foreach (const QString &s, searchStrings) {
+    for (const QString &s : qAsConst(searchStrings)) {
         QSet<uint> partResult = getMatchingChars(s.toLower());
         if (firstSubString) {
             result = partResult;
@@ -890,7 +896,7 @@ QVector<uint> KCharSelectData::find(const QString &needle)
 
     // remove results found by matching the code point to prevent duplicate results
     // while letting these characters stay at the beginning
-    foreach (uint c, returnRes) {
+    for (uint c : qAsConst(returnRes)) {
         result.remove(c);
     }
 
@@ -899,7 +905,7 @@ QVector<uint> KCharSelectData::find(const QString &needle)
     for (auto c : qAsConst(result)) {
         sortedResult.append(c);
     }
-    qSort(sortedResult);
+    std::sort(sortedResult.begin(), sortedResult.end());
 
     returnRes += sortedResult;
     return returnRes;
@@ -916,7 +922,7 @@ QSet<uint> KCharSelectData::getMatchingChars(const QString &s)
     QSet<uint> result;
 
     while (pos != index.constEnd() && pos.key().startsWith(s)) {
-        foreach (quint16 c, pos.value()) {
+        for (quint16 c : pos.value()) {
             result.insert(mapDataBaseToCodePoint(c));
         }
         ++pos;
@@ -950,7 +956,7 @@ QStringList KCharSelectData::splitString(const QString &s)
 void KCharSelectData::appendToIndex(Index *index, quint16 unicode, const QString &s)
 {
     const QStringList strings = splitString(s);
-    foreach (const QString &s, strings) {
+    for (const QString &s : strings) {
         (*index)[s.toLower()].append(unicode);
     }
 }
