@@ -1,7 +1,7 @@
 /* This file is part of the KDE libraries
     Copyright (C) 1997 Martin Jones (mjones@kde.org)
     Copyright (C) 2007 Pino Toscano (pino@kde.org)
-    Copyright (c) 2007 David Jarvie (software@astrojar.org.uk)
+    Copyright (c) 2007 David Jarvie (djarvie@kde.org)
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -28,6 +28,7 @@
 
 class KColorComboDelegate : public QAbstractItemDelegate
 {
+    Q_OBJECT
 public:
     enum ItemRoles {
         ColorRole = Qt::UserRole + 1
@@ -38,10 +39,10 @@ public:
     };
 
     KColorComboDelegate(QObject *parent = nullptr);
-    virtual ~KColorComboDelegate();
+    ~KColorComboDelegate() override;
 
-    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const Q_DECL_OVERRIDE;
-    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const Q_DECL_OVERRIDE;
+    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
+    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 };
 
 static QBrush k_colorcombodelegate_brush(const QModelIndex &index, int role)
@@ -250,6 +251,7 @@ QList<QColor> KColorCombo::colors() const
 {
     if (d->colorList.isEmpty()) {
         QList<QColor> list;
+        list.reserve(STANDARD_PALETTE_SIZE);
         for (int i = 0; i < STANDARD_PALETTE_SIZE; ++i) {
             list += standardColor(i);
         }
@@ -352,3 +354,4 @@ void KColorComboPrivate::addColors()
 }
 
 #include "moc_kcolorcombo.cpp"
+#include "kcolorcombo.moc"
