@@ -29,6 +29,8 @@ class KDateComboBoxPrivate;
 
 /**
  * @class KDateComboBox kdatecombobox.h KDateComboBox
+ *
+ * @short A combobox for dates.
  */
 class KWIDGETSADDONS_EXPORT KDateComboBox : public QComboBox
 {
@@ -68,7 +70,7 @@ public:
     /**
      * Destroy the widget
      */
-    virtual ~KDateComboBox();
+    ~KDateComboBox() override;
 
     /**
      * Return the currently selected date
@@ -82,16 +84,18 @@ public:
      *
      * If the user input is null then it is not valid
      *
-     * @see isNull()
      * @return if the current user input is valid
+     *
+     * @see isNull()
      */
     bool isValid() const;
 
     /**
      * Return if the current user input is null
      *
-     * @see isValid()
      * @return if the current user input is null
+     *
+     * @see isValid()
      */
     bool isNull() const;
 
@@ -129,17 +133,19 @@ public:
      * Return the map of dates listed in the drop-down and their displayed
      * string forms.
      *
-     * @see setDateMap()
      * @return the select date map
+     *
+     * @see setDateMap()
      */
     QMap<QDate, QString> dateMap() const;
 
 Q_SIGNALS:
 
     /**
-     * Signal if the date has been manually entered or selected by the user.
+     * Signal if the date has been manually entered (by typing a date and losing focus, or pressing Enter)
+     * or selected by the user (using the popup selector, or up, down, page up, page down keys, or the mouse wheel).
      *
-     * The returned date may be invalid.
+     * The emitted date may be invalid.
      *
      * @param date the new date
      */
@@ -149,7 +155,7 @@ Q_SIGNALS:
      * Signal if the date has been changed either manually by the user
      * or programatically.
      *
-     * The returned date may be invalid.
+     * The emitted date may be invalid.
      *
      * @param date the new date
      */
@@ -158,7 +164,7 @@ Q_SIGNALS:
     /**
      * Signal if the date is being manually edited by the user.
      *
-     * The returned date may be invalid.
+     * The emitted date may be invalid, or may not yet be what the user intends as the final date.
      *
      * @param date the new date
      */
@@ -220,14 +226,15 @@ public Q_SLOTS:
      * If the date is invalid, or greater than current maximum,
      * then the minimum will not be set.
      *
+     * @param minDate the minimum date
+     * @param minWarnMsg the minimum warning message
+     *
      * @see minimumDate()
      * @see maximumDate()
      * @see setMaximumDate()
      * @see setDateRange()
-     * @param minDate the minimum date
-     * @param minWarnMsg the minimum warning message
      */
-    void setMinimumDate(const QDate &minTime, const QString &minWarnMsg = QString());
+    void setMinimumDate(const QDate &minDate, const QString &minWarnMsg = QString());
 
     /**
      * Reset the minimum date to the default.
@@ -242,12 +249,13 @@ public Q_SLOTS:
      * If the date is invalid, or less than current minimum,
      * then the maximum will not be set.
      *
+     * @param maxDate the maximum date
+     * @param maxWarnMsg the maximum warning message
+     *
      * @see minimumDate()
      * @see maximumDate()
      * @see setMaximumDate()
      * @see setDateRange()
-     * @param maxDate the maximum date
-     * @param maxWarnMsg the maximum warning message
      */
     void setMaximumDate(const QDate &maxDate, const QString &maxWarnMsg = QString());
 
@@ -270,22 +278,23 @@ public Q_SLOTS:
      * default date format then the string should be null.  If you want a
      * separator to be displayed then set the string to "separator".
      *
-     * @see dateMap()
      * @param dateMap the map of dates able to be selected
+     *
+     * @see dateMap()
      */
     void setDateMap(QMap<QDate, QString> dateMap);
 
 protected:
 
-    bool eventFilter(QObject *object, QEvent *event) Q_DECL_OVERRIDE;
-    void showPopup() Q_DECL_OVERRIDE;
-    void hidePopup() Q_DECL_OVERRIDE;
-    void mousePressEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
-    void wheelEvent(QWheelEvent *event) Q_DECL_OVERRIDE;
-    void keyPressEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
-    void focusInEvent(QFocusEvent *event) Q_DECL_OVERRIDE;
-    void focusOutEvent(QFocusEvent *event) Q_DECL_OVERRIDE;
-    void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *object, QEvent *event) override;
+    void showPopup() override;
+    void hidePopup() override;
+    void mousePressEvent(QMouseEvent *event) override;
+    void wheelEvent(QWheelEvent *event) override;
+    void keyPressEvent(QKeyEvent *event) override;
+    void focusInEvent(QFocusEvent *event) override;
+    void focusOutEvent(QFocusEvent *event) override;
+    void resizeEvent(QResizeEvent *event) override;
 
     /**
      * Assign the date for the widget.
@@ -300,13 +309,6 @@ private:
 
     friend class KDateComboBoxPrivate;
     KDateComboBoxPrivate *const d;
-
-    Q_PRIVATE_SLOT(d, void clickDate())
-    Q_PRIVATE_SLOT(d, void selectDate(QAction *))
-    Q_PRIVATE_SLOT(d, void editDate(const QString &))
-    Q_PRIVATE_SLOT(d, void enterDate(const QDate &))
-    Q_PRIVATE_SLOT(d, void parseDate())
-
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KDateComboBox::Options)
