@@ -22,13 +22,14 @@
 #include "kdatetable_p.h"
 
 #include <QAction>
+#include <QActionEvent>
 #include <QFontDatabase>
 #include <QPainter>
 #include <QStyle>
 #include <QStyleOptionViewItem>
-#include <QActionEvent>
 #include <QApplication>
 #include <QMenu>
+#include <QDate>
 
 #include <cmath>
 
@@ -144,37 +145,37 @@ void KDateTable::initAccels()
     next->setObjectName(QStringLiteral("next"));
     next->setShortcuts(QKeySequence::keyBindings(QKeySequence::Forward));
     next->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    connect(next, SIGNAL(triggered(bool)), SLOT(nextMonth()));
+    connect(next, &QAction::triggered, this, [this]() { d->nextMonth(); });
 
     QAction *prior = new QAction(this);
     prior->setObjectName(QStringLiteral("prior"));
     prior->setShortcuts(QKeySequence::keyBindings(QKeySequence::Back));
     prior->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    connect(prior, SIGNAL(triggered(bool)), SLOT(previousMonth()));
+    connect(prior, &QAction::triggered, this, [this]() { d->previousMonth(); });
 
     QAction *beginMonth = new QAction(this);
     beginMonth->setObjectName(QStringLiteral("beginMonth"));
     beginMonth->setShortcuts(QKeySequence::keyBindings(QKeySequence::MoveToStartOfDocument));
     beginMonth->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    connect(beginMonth, SIGNAL(triggered(bool)), SLOT(beginningOfMonth()));
+    connect(beginMonth, &QAction::triggered, this, [this]() { d->beginningOfMonth(); });
 
     QAction *endMonth = new QAction(this);
     endMonth->setObjectName(QStringLiteral("endMonth"));
     endMonth->setShortcuts(QKeySequence::keyBindings(QKeySequence::MoveToEndOfDocument));
     endMonth->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    connect(endMonth, SIGNAL(triggered(bool)), SLOT(endOfMonth()));
+    connect(endMonth, &QAction::triggered, this, [this]() { d->endOfMonth(); });
 
     QAction *beginWeek = new QAction(this);
     beginWeek->setObjectName(QStringLiteral("beginWeek"));
     beginWeek->setShortcuts(QKeySequence::keyBindings(QKeySequence::MoveToStartOfLine));
     beginWeek->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    connect(beginWeek, SIGNAL(triggered(bool)), SLOT(beginningOfWeek()));
+    connect(beginWeek, &QAction::triggered, this, [this]() { d->beginningOfWeek(); });
 
     QAction *endWeek = new QAction(this);
     endWeek->setObjectName(QStringLiteral("endWeek"));
     endWeek->setShortcuts(QKeySequence::keyBindings(QKeySequence::MoveToEndOfLine));
     endWeek->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    connect(endWeek, SIGNAL(triggered(bool)), SLOT(endOfWeek()));
+    connect(endWeek, &QAction::triggered, this, [this]() { d->endOfWeek(); });
 }
 
 int KDateTable::posFromDate(const QDate &date)
@@ -241,7 +242,6 @@ void KDateTable::paintCell(QPainter *painter, int row, int col)
     double h = (height() / (double) d->m_numWeekRows) - 1;
     QRectF cell = QRectF(0, 0, w, h);
     QString cellText;
-    QPen pen;
     QColor cellBackgroundColor, cellTextColor;
     QFont cellFont = QFontDatabase::systemFont(QFontDatabase::GeneralFont);
     bool workingDay = false;
@@ -300,7 +300,7 @@ void KDateTable::paintCell(QPainter *painter, int row, int col)
         if (validDay) {
             cellText = QString::number(cellDate.day());
         } else {
-            cellText = QLatin1String("");
+            cellText = QString();
         }
 
         if (! validDay || cellDate.month() != d->m_date.month()) {
@@ -378,7 +378,7 @@ void KDateTable::paintCell(QPainter *painter, int row, int col)
         painter->setBrush(cellBackgroundColor);
         painter->drawRect(cell);
     } else if (cellBackgroundColor != palette().color(backgroundRole()) || pos == d->m_hoveredPos) {
-        QStyleOptionViewItemV4 opt;
+        QStyleOptionViewItem opt;
         opt.initFrom(this);
         opt.rect = cell.toRect();
         if (cellBackgroundColor != palette().color(backgroundRole())) {
@@ -391,7 +391,7 @@ void KDateTable::paintCell(QPainter *painter, int row, int col)
             opt.state &= ~QStyle::State_MouseOver;
         }
         opt.showDecorationSelected = true;
-        opt.viewItemPosition = QStyleOptionViewItemV4::OnlyOne;
+        opt.viewItemPosition = QStyleOptionViewItem::OnlyOne;
         style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, painter, this);
     }
 
@@ -524,7 +524,7 @@ void KDateTable::setFontSize(int size)
 
 void KDateTable::wheelEvent(QWheelEvent *e)
 {
-    setDate(d->m_date.addMonths(-(int)(e->delta() / 120)));
+    setDate(d->m_date.addMonths(-(int)(e->angleDelta().y() / 120)));
     e->accept();
 }
 
@@ -634,8 +634,8 @@ bool KDateTable::setDate(const QDate &toDate)
 
     QDate oldDate = date();
     d->setDate(toDate);
-    emit(dateChanged(date(), oldDate));
-    emit(dateChanged(date()));
+    emit dateChanged(date(), oldDate);
+    emit dateChanged(date());
     update();
 
     return true;
@@ -662,7 +662,7 @@ QSize KDateTable::sizeHint() const
         return QSize(qRound(d->m_maxCell.width() * d->m_numDayColumns),
                      (qRound(d->m_maxCell.height() + 2) * d->m_numWeekRows));
     } else {
-        //qDebug() << "KDateTable::sizeHint: obscure failure - " << endl;
+        //qCDebug(KWidgetsAddonsLog) << "KDateTable::sizeHint: obscure failure - " << endl;
         return QSize(-1, -1);
     }
 }
