@@ -22,11 +22,10 @@
 
 #include <QLabel>
 #include <QPushButton>
-#include <QLayout>
 #include <QFontDatabase>
 #include <QFontInfo>
 #include <QFontDialog>
-#include <QLocale>
+#include <QHBoxLayout>
 
 #include <kfontchooser.h>
 
@@ -38,7 +37,7 @@ static QFont nearestExistingFont(const QFont &font)
 {
     QFontDatabase dbase;
 
-    // Initialize font data accoring to given font object.
+    // Initialize font data according to given font object.
     QString family = font.family();
     QString style = dbase.styleString(font);
     qreal size = font.pointSizeF();
@@ -61,12 +60,12 @@ static QFont nearestExistingFont(const QFont &font)
     // Check if the family has the requested size.
     // Only for bitmap fonts.
     if (!dbase.isSmoothlyScalable(family, style)) {
-        QList<int> sizes = dbase.smoothSizes(family, style);
+        const QList<int> sizes = dbase.smoothSizes(family, style);
         if (!sizes.contains(size)) {
             // Find nearest available size.
             int mindiff = 1000;
             int refsize = size;
-            Q_FOREACH (int lsize, sizes) {
+            for (int lsize : sizes) {
                 int diff = qAbs(refsize - lsize);
                 if (mindiff > diff) {
                     mindiff = diff;
@@ -97,8 +96,8 @@ public:
     KFontRequester *q;
     bool m_onlyFixed;
     QString m_sampleText, m_title;
-    QLabel *m_sampleLabel;
-    QPushButton *m_button;
+    QLabel *m_sampleLabel = nullptr;
+    QPushButton *m_button = nullptr;
     QFont m_selFont;
 };
 
@@ -108,10 +107,10 @@ KFontRequester::KFontRequester(QWidget *parent, bool onlyFixed)
     d->m_onlyFixed = onlyFixed;
 
     QHBoxLayout *layout = new QHBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     d->m_sampleLabel = new QLabel(this);
-    d->m_button = new QPushButton(tr("Choose..."), this);
+    d->m_button = new QPushButton(QIcon::fromTheme(QStringLiteral("document-edit")), QString(), this);
 
     d->m_sampleLabel->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
     setFocusProxy(d->m_button);
@@ -120,7 +119,7 @@ KFontRequester::KFontRequester(QWidget *parent, bool onlyFixed)
     layout->addWidget(d->m_sampleLabel, 1);
     layout->addWidget(d->m_button);
 
-    connect(d->m_button, SIGNAL(clicked()), SLOT(_k_buttonClicked()));
+    connect(d->m_button, &QPushButton::clicked, this, [this] { d->_k_buttonClicked(); });
 
     d->displaySampleText();
     d->setToolTip();
@@ -217,7 +216,7 @@ void KFontRequester::KFontRequesterPrivate::displaySampleText()
 
 void KFontRequester::KFontRequesterPrivate::setToolTip()
 {
-    m_button->setToolTip(tr("Click to select a font"));
+    m_button->setToolTip(tr("Choose Font..."));
 
     m_sampleLabel->setToolTip(QString());
     m_sampleLabel->setWhatsThis(QString());
@@ -225,11 +224,11 @@ void KFontRequester::KFontRequesterPrivate::setToolTip()
     if (m_title.isNull()) {
         m_sampleLabel->setToolTip(tr("Preview of the selected font"));
         m_sampleLabel->setWhatsThis(tr("This is a preview of the selected font. You can change it"
-                                       " by clicking the \"Choose...\" button."));
+                                       " by clicking the \"Choose Font...\" button."));
     } else {
         m_sampleLabel->setToolTip(tr("Preview of the \"%1\" font").arg(m_title));
         m_sampleLabel->setWhatsThis(tr("This is a preview of the \"%1\" font. You can change it"
-                                       " by clicking the \"Choose...\" button.").arg(m_title));
+                                       " by clicking the \"Choose Font...\" button.").arg(m_title));
     }
 }
 
