@@ -27,12 +27,10 @@
 #include "moc_kmultitabbar.cpp"
 #include "moc_kmultitabbar_p.cpp"
 
-#include <QActionEvent>
-#include <QLayout>
 #include <QPainter>
-#include <QFontMetrics>
 #include <QStyle>
 #include <QStyleOptionButton>
+#include <QMouseEvent>
 
 #include <math.h>
 
@@ -61,11 +59,11 @@ KMultiTabBarInternal::KMultiTabBarInternal(QWidget *parent, KMultiTabBar::KMulti
     } else {
         mainLayout = new QHBoxLayout(this);
     }
-    mainLayout->setMargin(0);
+    mainLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->setSpacing(0);
     mainLayout->addStretch();
     setFrameStyle(NoFrame);
-    setBackgroundRole(QPalette::Background);
+    setBackgroundRole(QPalette::Window);
 }
 
 KMultiTabBarInternal::~KMultiTabBarInternal()
@@ -150,7 +148,7 @@ KMultiTabBarButton::KMultiTabBarButton(const QIcon &icon, const QString &text,
                                        int id, QWidget *parent)
     : QPushButton(icon, text, parent), m_id(id), d(nullptr)
 {
-    connect(this, SIGNAL(clicked()), this, SLOT(slotClicked()));
+    connect(this, &QPushButton::clicked, this, &KMultiTabBarButton::slotClicked);
 
     // we can't see the focus, so don't take focus. #45557
     // If keyboard navigation is wanted, then only the bar should take focus,
@@ -164,7 +162,7 @@ KMultiTabBarButton::KMultiTabBarButton(const QPixmap &pic, const QString &text,
                                        int id, QWidget *parent)
     : QPushButton(QIcon(pic), text, parent), m_id(id), d(nullptr)
 {
-    connect(this, SIGNAL(clicked()), this, SLOT(slotClicked()));
+    connect(this, &QPushButton::clicked, this, &KMultiTabBarButton::slotClicked);
 
     // we can't see the focus, so don't take focus. #45557
     // If keyboard navigation is wanted, then only the bar should take focus,
@@ -532,7 +530,7 @@ KMultiTabBar::KMultiTabBar(KMultiTabBarPosition pos, QWidget *parent)
         d->m_l = new QHBoxLayout(this);
         setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed/*, true*/);
     }
-    d->m_l->setMargin(0);
+    d->m_l->setContentsMargins(0, 0, 0, 0);
     d->m_l->setSpacing(0);
 
     d->m_internal = new KMultiTabBarInternal(this, pos);
@@ -568,7 +566,7 @@ int KMultiTabBar::appendButton(const QIcon &icon, int id, QMenu *popup, const QS
     return 0;
 }
 
-#ifndef KWIDGETSADDONS_NO_DEPRECATED
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 13)
 int KMultiTabBar::appendButton(const QPixmap &pic, int id, QMenu *popup, const QString &x)
 {
     // reuse icon variant
@@ -599,7 +597,7 @@ int KMultiTabBar::appendTab(const QIcon &icon, int id, const QString &text)
     return 0;
 }
 
-#ifndef KWIDGETSADDONS_NO_DEPRECATED
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 13)
 int KMultiTabBar::appendTab(const QPixmap &pic, int id, const QString &text)
 {
     d->m_internal->appendTab(pic, id, text);
@@ -634,7 +632,7 @@ void KMultiTabBar::removeButton(int id)
         }
     }
 
-    if (d->m_buttons.count() == 0) {
+    if (d->m_buttons.isEmpty()) {
         d->m_btnTabSep->hide();
     }
 }
