@@ -20,12 +20,11 @@
 
 #include "kratingpainter.h"
 
-#include <QDebug>
 #include <QPainter>
 #include <QPixmap>
 #include <QIcon>
-#include <QtCore/QRect>
-#include <QtCore/QPoint>
+#include <QRect>
+#include <QPoint>
 
 class Q_DECL_HIDDEN KRatingPainter::Private
 {
