@@ -42,7 +42,7 @@
  * @code
 KTitleWidget *titleWidget = new KTitleWidget(this);
 titleWidget->setText(i18n("Title"));
-titleWidget->setPixmap(QIcon::fromTheme("screen").pixmap(22, 22));
+titleWidget->setIcon(QIcon::fromTheme("screen"));
  * @endcode
  *
  * Use it with an own widget:
@@ -51,7 +51,7 @@ KTitleWidget *checkboxTitleWidget = new KTitleWidget(this);
 
 QWidget *checkBoxTitleMainWidget = new QWidget(this);
 QVBoxLayout *titleLayout = new QVBoxLayout(checkBoxTitleMainWidget);
-titleLayout->setMargin(6);
+titleLayout->setContentsMargins(6, 6, 6, 6);
 
 QCheckBox *checkBox = new QCheckBox("Text Checkbox", checkBoxTitleMainWidget);
 titleLayout->addWidget(checkBox);
@@ -99,7 +99,7 @@ public:
      */
     explicit KTitleWidget(QWidget *parent = nullptr);
 
-    virtual ~KTitleWidget();
+    ~KTitleWidget() override;
 
     /**
      * @param widget Widget displayed on the title widget.
@@ -139,6 +139,14 @@ public:
      */
     int autoHideTimeout() const;
 
+    /**
+     * @return The level of this title: it influences the font size following the guidelines at
+     *         https://www.my-scratch.de/HIG/style/typography.html
+     *         It also corresponds to the level api of Kirigami Heading for QML applications
+     * @since 5.53
+     */
+    int level();
+
 public Q_SLOTS:
     /**
      * @param text Text displayed on the label. It can either be plain text or rich text. If it
@@ -163,6 +171,14 @@ public Q_SLOTS:
      */
     void setComment(const QString &comment, MessageType type = PlainMessage);
 
+    /**
+     * Set the icon to display in the header.
+     * @param icon the icon to display in the header.
+     * @param alignment alignment of the icon (default is right aligned).
+     * @since 5.63
+     */
+    void setIcon(const QIcon &icon, ImageAlignment alignment = ImageRight);
+
     /**
      * @param pixmap Pixmap displayed in the header. The pixmap is by default right, but
      * @param alignment can be used to display it also left.
@@ -170,19 +186,27 @@ public Q_SLOTS:
      */
     void setPixmap(const QPixmap &pixmap, ImageAlignment alignment = ImageRight);
 
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 63)
     /**
      * @param icon name of the icon to display in the header. The pixmap is by default right, but
      * @param alignment can be used to display it also left.
      * @see pixmap()
+     * @deprecated since 5.63 use setIcon() instead
      */
+    KWIDGETSADDONS_DEPRECATED_VERSION(5, 63, "Use KTitleWidget::setIcon(const QIcon &, ImageAlignment)")
     void setPixmap(const QString &icon, ImageAlignment alignment = ImageRight);
+#endif
 
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 63)
     /**
      * @param icon the icon to display in the header. The pixmap is by default right, but
      * @param alignment can be used to display it also left.
      * @see pixmap()
+     * @deprecated since 5.63 use setIcon() instead
      */
+    KWIDGETSADDONS_DEPRECATED_VERSION(5, 63, "Use KTitleWidget::setIcon(const QIcon &, ImageAlignment)")
     void setPixmap(const QIcon &icon, ImageAlignment alignment = ImageRight);
+#endif
 
     /**
      * @param type the type of message icon to display in the header. The pixmap is by default right, but
@@ -198,10 +222,18 @@ public Q_SLOTS:
      */
     void setAutoHideTimeout(int msecs);
 
+    /**
+     * Sets the level of this title, similar to HTML's h1 h2 h3...
+     * follows KDE HIG https://www.my-scratch.de/HIG/style/typography.html
+     * @param level the level of the title, 1 is the biggest font and most important, descending
+     * @since 5.53
+     */
+    void setLevel(int level);
+
 protected:
-    void changeEvent(QEvent *e) Q_DECL_OVERRIDE;
-    void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
-    bool eventFilter(QObject *object, QEvent *event) Q_DECL_OVERRIDE;
+    void changeEvent(QEvent *e) override;
+    void showEvent(QShowEvent *event) override;
+    bool eventFilter(QObject *object, QEvent *event) override;
 
 private:
     class Private;
